@@ -1,12 +1,13 @@
 """Configuration management for Client"""
-import logging
+import copy
 from typing import Dict
 from typing import List
 from typing import Optional
+from typing import Union
 
 from idpyoidc.configure import Base
 from idpyoidc.logging import configure_logging
-
+from idpyoidc.message.oidc import RegistrationResponse
 from .util import lower_or_upper
 
 try:
@@ -24,16 +25,16 @@ URIS = [
 ]
 
 
-class RPConfiguration(Base):
+class RPHConfiguration(Base):
     def __init__(
-        self,
-        conf: Dict,
-        base_path: Optional[str] = "",
-        entity_conf: Optional[List[dict]] = None,
-        domain: Optional[str] = "127.0.0.1",
-        port: Optional[int] = 80,
-        file_attributes: Optional[List[str]] = None,
-        dir_attributes: Optional[List[str]] = None,
+            self,
+            conf: Dict,
+            base_path: Optional[str] = "",
+            entity_conf: Optional[List[dict]] = None,
+            domain: Optional[str] = "127.0.0.1",
+            port: Optional[int] = 80,
+            file_attributes: Optional[List[str]] = None,
+            dir_attributes: Optional[List[str]] = None,
     ):
 
         Base.__init__(
@@ -46,7 +47,11 @@ class RPConfiguration(Base):
             dir_attributes=dir_attributes,
         )
 
-        self.key_conf = lower_or_upper(conf, "rp_keys") or lower_or_upper(conf, "oidc_keys")
+        for _attr in ["key_conf", "rp_keys", "oidc_keys"]:
+            _val = lower_or_upper(conf, _attr)
+            if _val:
+                self.key_conf = _val
+                break
 
         hash_seed = lower_or_upper(conf, "hash_seed")
         if not hash_seed:
@@ -58,17 +63,18 @@ class RPConfiguration(Base):
 
         self.default = lower_or_upper(conf, "default", {})
 
-        for param in ["services", "client_preferences", "add_ons"]:
+        for param in ["services", "metadata", "add_ons", "usage"]:
             _val = lower_or_upper(conf, param, {})
             if _val and param not in self.default:
                 self.default[param] = _val
 
         self.clients = lower_or_upper(conf, "clients")
-        for id, client in self.clients.items():
-            for param in ["services", "client_preferences", "add_ons"]:
-                if param not in client:
-                    if param in self.default:
-                        client[param] = self.default[param]
+        if self.clients:
+            for id, client in self.clients.items():
+                for param in ["services", "usage", "add_ons", 'metadata']:
+                    if param not in client:
+                        if param in self.default:
+                            client[param] = self.default[param]
 
         if entity_conf:
             self.extend(
@@ -82,17 +88,17 @@ class RPConfiguration(Base):
 
 
 class Configuration(Base):
-    """RP Configuration"""
+    """ Configuration for a single RP """
 
     def __init__(
-        self,
-        conf: Dict,
-        base_path: str = "",
-        entity_conf: Optional[List[dict]] = None,
-        file_attributes: Optional[List[str]] = None,
-        domain: Optional[str] = "",
-        port: Optional[int] = 0,
-        dir_attributes: Optional[List[str]] = None,
+            self,
+            conf: Dict,
+            base_path: str = "",
+            entity_conf: Optional[List[dict]] = None,
+            file_attributes: Optional[List[str]] = None,
+            domain: Optional[str] = "",
+            port: Optional[int] = 0,
+            dir_attributes: Optional[List[str]] = None,
     ):
         Base.__init__(
             self,
@@ -102,11 +108,18 @@ class Configuration(Base):
             dir_attributes=dir_attributes,
         )
 
+        _del_key = []
+        for attr, val in self.conf.items():
+            if attr in ["issuer", "key_conf"]:
+                setattr(self, attr, val)
+                _del_key.append(attr)
+
+        for _key in _del_key:
+            del self.conf[_key]
+
         log_conf = conf.get("logging")
         if log_conf:
             self.logger = configure_logging(config=log_conf).getChild(__name__)
-        else:
-            self.logger = logging.getLogger("client")
 
         self.web_conf = lower_or_upper(conf, "webserver")
 
@@ -120,3 +133,15 @@ class Configuration(Base):
                 port=port,
                 dir_attributes=dir_attributes,
             )
+
+
+def get_configuration(config: Optional[Union[dict, Configuration]] = None):
+    if config is None:
+        config = Configuration({})
+    elif isinstance(config, dict):
+        if not isinstance(config, Base):
+            config = Configuration(copy.deepcopy(config))
+    else:  # not None and not a dict ??
+        raise ValueError("Configuration in a format I don't support")
+
+    return config
