@@ -12,6 +12,7 @@ from idpyoidc.client.service import SUCCESSFUL
 from idpyoidc.client.service import Service
 from idpyoidc.client.util import do_add_ons
 from idpyoidc.client.util import get_deserialization_method
+from idpyoidc.configure import Configuration
 from idpyoidc.exception import FormatError
 from idpyoidc.message import Message
 from idpyoidc.message.oauth2 import is_error_message
@@ -40,9 +41,12 @@ class Client(Entity):
         services=None,
         jwks_uri="",
         httpc_params=None,
+        client_type: Optional[str] = ""
     ):
         """
 
+        :type client_type: str
+        :param client_type: What kind of client this is. Presently 'oauth2' or 'oidc'
         :param keyjar: A py:class:`idpyoidc.key_jar.KeyJar` instance
         :param config: Configuration information passed on to the
             :py:class:`idpyoidc.client.service_context.ServiceContext`
@@ -54,6 +58,9 @@ class Client(Entity):
         :return: Client instance
         """
 
+        if not client_type:
+            client_type = "oauth2"
+
         Entity.__init__(
             self,
             keyjar=keyjar,
@@ -61,12 +68,18 @@ class Client(Entity):
             services=services,
             jwks_uri=jwks_uri,
             httpc_params=httpc_params,
+            client_type=client_type
         )
 
         self.http = httplib or HTTPLib(httpc_params)
 
-        if "add_ons" in config:
-            do_add_ons(config["add_ons"], self._service)
+        if isinstance(config, Configuration):
+            _add_ons = config.conf.get("add_ons")
+        else:
+            _add_ons = config.get("add_ons")
+
+        if _add_ons:
+            do_add_ons(_add_ons, self._service)
 
         # just ignore verify_ssl until it goes away
         self.verify_ssl = self.httpc_params.get("verify", True)
