@@ -11,10 +11,11 @@ class AccessTokenResponse(Message):
     """
     Access token response
     """
+
     c_param = {
         "access_token": SINGLE_REQUIRED_STRING,
         "token_type": SINGLE_REQUIRED_STRING,
-        "scope": SINGLE_OPTIONAL_STRING
+        "scope": SINGLE_OPTIONAL_STRING,
     }
 
 
@@ -22,11 +23,11 @@ class AccessToken(access_token.AccessToken):
     msg_type = oauth2.AccessTokenRequest
     response_cls = AccessTokenResponse
     error_msg = oauth2.TokenErrorResponse
-    response_body_type = 'urlencoded'
+    response_body_type = "urlencoded"
 
 
 class UserInfo(userinfo.UserInfo):
     response_cls = Message
     error_msg = ResponseMessage
-    default_authn_method = ''
-    http_method = 'GET'
+    default_authn_method = ""
+    http_method = "GET"
