@@ -1,5 +1,3 @@
-import os
-
 # from cryptojwt.jwe.fernet import DEFAULT_ITERATIONS
 
 DEF_SIGN_ALG = {
@@ -17,3 +15,5 @@ JWT_BEARER = "urn:ietf:params:oauth:client-assertion-type:jwt-bearer"
 DIVIDER = ";;"
 
 DEFAULT_TOKEN_LIFETIME = 1800
+
+DEFAULT_REQUESTED_TOKEN_TYPE = "urn:ietf:params:oauth:token-type:access_token"
