@@ -266,3 +266,16 @@ class IDToken(SessionToken):
 
 
 SHORT_TYPE_NAME = {"authorization_code": "A", "access_token": "T", "refresh_token": "R"}
+
+TOKEN_MAP = {
+    "authorization_code": AuthorizationCode,
+    "access_token": AccessToken,
+    "refresh_token": RefreshToken,
+    "id_token": IDToken,
+}
+
+TOKEN_TYPES_MAPPING = {
+    "urn:ietf:params:oauth:token-type:access_token": "access_token",
+    "urn:ietf:params:oauth:token-type:refresh_token": "refresh_token",
+    "urn:ietf:params:oauth:token-type:id_token": "id_token",
+}
