@@ -1,5 +1,6 @@
 import importlib
 import json
+import logging
 import os
 import secrets
 import sys
@@ -13,6 +14,8 @@ from urllib.parse import urlunsplit
 import yaml
 from cryptojwt.utils import importer
 
+logger = logging.getLogger(__name__)
+
 
 def rndstr(size=16):
     """
@@ -135,3 +138,15 @@ def add_path(url, path):
             return "{}{}".format(url, path)
         else:
             return "{}/{}".format(url, path)
+
+def qualified_name(cls):
+    """Does both classes and class instances
+
+    :param cls: The item, class or class instance
+    :return: fully qualified class name
+    """
+
+    try:
+        return cls.__module__ + "." + cls.name
+    except AttributeError:
+        return cls.__module__ + "." + cls.__name__
